docs.rs failed to build bmux_decoration_plugin_api-0.0.1-alpha.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
bmux_decoration_plugin_api
Typed public API of the BMUX decoration plugin, generated from a BPDL schema. Depend on this crate (not the plugin implementation) when your plugin needs to query or adjust the current pane decoration style.